@@ -28,7 +28,6 @@ using System.Timers;
 
 public class GameDrawingArea : DrawingArea
 {
-
 	public enum Modes
 	{	
 		Welcome,
@@ -43,15 +42,16 @@ public class GameDrawingArea : DrawingArea
 	private ArrayListIndicesRandom random_indices;
 	private const int tips_count = 10;
 	private const int tips_shown = 4;
-	private System.Timers.Timer timer;
-	private int countdown_time;
-	private EventHandler finish;
+	private CountDown countdown;
+	private bool rtl;
 
 	public GameDrawingArea ()
 	{
 		mode = Modes.Welcome;
 		puzzle = null;
 		session = null;
+		countdown = null;
+		rtl = Direction == Gtk.TextDirection.Rtl;
 	}
 
 	public GameSession GameSession {
@@ -62,15 +62,6 @@ public class GameDrawingArea : DrawingArea
 		}
 	}
 
-	private void DrawBackground (CairoContextEx gr)
-	{
-		gr.Save ();
-		gr.Color = new Cairo.Color (1, 1, 1);
-		gr.Paint ();	
-		gr.Stroke ();
-		gr.Restore ();		
-	}
-
 	private void DrawBand (CairoContextEx gr, double x, double y)
 	{
 		gr.Save ();
@@ -80,140 +71,89 @@ public class GameDrawingArea : DrawingArea
 		gr.Restore ();		
 	}
 
-	private void DrawWelcome (CairoContextEx gr, int area_width, int area_height)
+	public void OnDrawCountDown (EventHandler OnFinish)
 	{
-		double y = 0.07;
-		double space = 0.21;
-		double line_space = 0.06;
-		ImageSurface image;
-
-		gr.Scale (area_width, area_height);
-		DrawBackground (gr);
-		gr.Color = new Cairo.Color (0, 0, 0, 1);
-		gr.Save ();
-		gr.SetFontSize (0.035);
-		gr.SelectFontFace ("Sans", FontSlant.Normal, FontWeight.Bold);
-
-		gr.MoveTo (0.05, y);
-		gr.ShowText (String.Format (Catalog.GetString ("Welcome to gbrainy {0}"), Defines.VERSION));
-		gr.Stroke ();
-
-		gr.Restore ();
-		gr.SetFontSize (0.03);
-		gr.DrawStringWithWrapping (0.05, y + 0.08, line_space, Catalog.GetString ("gbrainy is a brain teaser game and trainer to have fun and to keep your brain trained. It includes:"));
-
-		y = 0.26;
-		image = new ImageSurface (Defines.DATA_DIR + "logic-games-80.png");
-		if (image.Width > 0) {
-			gr.Save ();
-			gr.Translate (0.05, y);
-			gr.Scale (0.8 / area_width, 0.8 / area_height);
-			gr.SetSourceSurface (image, 0, 0);
-			gr.Paint ();
-			gr.Restore ();
-		}
-		gr.DrawStringWithWrapping (0.23, y + 0.03, line_space, Catalog.GetString ("Logic puzzles. Designed to challenge your reasoning and thinking skills."));
-
-		y += space;
-		image = new ImageSurface (Defines.DATA_DIR + "math-games-80.png");
-		if (image.Width > 0) {
-			gr.Save ();
-			gr.Translate (0.05, y);
-			gr.Scale (0.8 / area_width, 0.8 / area_height);
-			gr.SetSourceSurface (image, 0, 0);
-			gr.Paint ();
-			gr.Restore ();
-		}
-		gr.DrawStringWithWrapping (0.23, y + 0.03, line_space, Catalog.GetString ("Mental calculation. Based on arithmetical operations that test your mental calculation abilities."));
-
-		y += space;
-		image = new ImageSurface (Defines.DATA_DIR + "memory-games-80.png");
-		if (image.Width > 0) {
-			gr.Save ();
-			gr.Translate (0.05, y);
-			gr.Scale (0.8 / area_width, 0.8 / area_height);
-			gr.SetSourceSurface (image, 0, 0);
-			gr.Paint ();
-			gr.Restore ();
-		}
-		gr.DrawStringWithWrapping (0.23, y + 0.03, line_space, Catalog.GetString ("Memory trainers. To prove and enhance your short term memory."));
-		gr.Stroke ();
-
-		gr.DrawStringWithWrapping (0.05, y + 0.23, line_space, Catalog.GetString ("Use the Settings to adjust the difficulty level of the game."));
-		gr.Stroke ();
-	}
-
-	private void TimerUpdater (object source, ElapsedEventArgs e)
-	{
-		lock (this) {
-			if (countdown_time == 1) {
-				EndDrawCountDown ();
-				Application.Invoke ( delegate { 
-					finish (this, EventArgs.Empty);
-				});
-			}
-			countdown_time--;
-			Application.Invoke ( delegate { QueueDraw (); });
-		}
+		mode = Modes.CountDown;
+		QueueDraw ();	
+		countdown = new CountDown (this, OnFinish);
 	}
 
 	public void EndDrawCountDown ()
 	{
-		if (timer == null)
+		if (countdown == null)
 			return;
 
-		timer.Enabled = false;
-		timer.Dispose ();
-		timer = null;
+		countdown.EndDrawCountDown ();
 	}
 
-	public void OnDrawCountDown (EventHandler OnFinish)
+	private void DrawImage (CairoContextEx gr, double x, double y, string img)
 	{
-		mode = Modes.CountDown;
-		QueueDraw ();
-		
-		countdown_time = 3;
-		timer = new System.Timers.Timer ();
-		timer.Elapsed += TimerUpdater;
-		timer.Interval = (1 * 1000); // 1 second
-		timer.Enabled = true;
-		finish = OnFinish;
+		SVGImage image;
+
+		try {
+			image = new SVGImage (img);
+		}
+		catch (Exception)
+		{
+			return;
+		}
+
+		gr.Save ();
+		gr.Translate (x, y);
+		gr.Scale (0.15 / image.Width, 0.15 / image.Height);
+		image.RenderToCairo (gr.Handle);
+		gr.Restore ();
+		image.Dispose ();
 	}
 
-	private void DrawCountDown (CairoContextEx gr, int area_width, int area_height)
+	private void DrawWelcome (CairoContextEx gr, int area_width, int area_height)
 	{
+		double y = 0.05;
+		double space = 0.20;
+
 		gr.Scale (area_width, area_height);
-
-		gr.Color = new Cairo.Color (0.8, 0.8, 0.8);
-		gr.Paint ();
-
-		gr.LineWidth = 0.01;
+		gr.DrawBackground ();
 		gr.Color = new Cairo.Color (0, 0, 0, 1);
 
-		gr.SetFontSize (0.033);
-		gr.DrawTextCentered (0.5, 0.1, Catalog.GetString ("Get ready to memorize the next objects..."));
+		gr.MoveTo (0.05, y);
+		gr.ShowPangoText (String.Format (Catalog.GetString ("Welcome to gbrainy {0}"), Defines.VERSION), true, -1, 0);
 		gr.Stroke ();
 
-		gr.SetFontSize (0.4);
-		gr.MoveTo (0.37, 0.63);
-		gr.ShowText (countdown_time.ToString ());
-		gr.Stroke ();
+		gr.DrawStringWithWrapping (0.05, y + 0.07, Catalog.GetString ("gbrainy is a brain teaser game and trainer to have fun and to keep your brain trained. It includes:"));
 
-		gr.Arc (0.5, 0.5, 0.25, 0, 2 * Math.PI);
-		gr.Stroke ();
-		gr.Arc (0.5, 0.5, 0.28, 0, 2 * Math.PI);
-		gr.Stroke ();
+		y = 0.25;
 
+		DrawImage (gr, rtl ? 0.75 : 0.05, y, Defines.DATA_DIR + "logic-games.svg");
+		gr.DrawStringWithWrapping (rtl ? 0.05 : 0.23, y + 0.01, 
+			Catalog.GetString ("Logic puzzles. Designed to challenge your reasoning and thinking skills."), 
+			rtl ? 0.65 : -1);
+
+		y += space;
+
+		DrawImage (gr, rtl ? 0.75 : 0.05, y, Defines.DATA_DIR + "math-games.svg");
+		gr.DrawStringWithWrapping (rtl ? 0.05 : 0.23, y + 0.01, 
+			Catalog.GetString ("Mental calculation. Based on arithmetical operations that test your mental calculation abilities."),
+			rtl ? 0.65 : -1);
+
+		y += space;
+		DrawImage (gr, rtl ? 0.75 : 0.05, y, Defines.DATA_DIR + "memory-games.svg");
+		gr.DrawStringWithWrapping (rtl ? 0.05 : 0.23, y + 0.01, 
+			Catalog.GetString ("Memory trainers. To prove and enhance your short term memory."),
+			rtl ? 0.65 : -1);
+
+		gr.DrawStringWithWrapping (0.05, y + 0.2,  Catalog.GetString ("Use the Settings to adjust the difficulty level of the game."));
+		gr.Stroke ();
 	}
 
+
 	public void DrawBar (CairoContextEx gr, double x, double y, double w, double h, double percentage)
 	{
 		double per = percentage / 100;
 	
 		gr.Rectangle (x, y - h * per, w, h * per);
 		gr.FillGradient (x, y - h * per, w, h * per, new Cairo.Color (0, 0, 1));
-		gr.MoveTo (x, (y - 0.02) - h * per);
-		gr.ShowText (String.Format ("{0}%", percentage));
+		gr.MoveTo (x, (y - 0.04) - h * per);
+		gr.ShowPangoText (String.Format ("{0}%", percentage));
 		gr.Stroke ();
 
 		gr.Save ();
@@ -242,38 +182,35 @@ public class GameDrawingArea : DrawingArea
 
 		x = x + 0.1;
 		DrawBar (gr, x, y + area_h, bar_w, bar_h, session.TotalScore);
-		gr.DrawTextCentered (x + bar_w / 2, y + area_h + 0.05, Catalog.GetString ("Total"));
+		gr.DrawTextCentered (x + bar_w / 2, y + area_h + 0.03, Catalog.GetString ("Total"));
 
 		x = x + 0.2;
 		DrawBar (gr, x, y + area_h, bar_w, bar_h, session.LogicScore);
-		gr.DrawTextCentered (x + bar_w / 2, y + area_h + 0.05, Catalog.GetString ("Logic")); 
+		gr.DrawTextCentered (x + bar_w / 2, y + area_h + 0.03, 	Catalog.GetString ("Logic")); 
 
 		x = x + 0.2;
 		DrawBar (gr, x, y + area_h, bar_w, bar_h, session.MathScore);
-		gr.DrawTextCentered (x + bar_w / 2, y + area_h + 0.05, Catalog.GetString ("Calculation"));
+		gr.DrawTextCentered (x + bar_w / 2, y + area_h + 0.03, Catalog.GetString ("Calculation"));
 
 		x = x + 0.2;
 		DrawBar (gr, x, y + area_h, bar_w, bar_h, session.MemoryScore);
-		gr.DrawTextCentered (x + bar_w / 2, y + area_h + 0.05, Catalog.GetString ("Memory"));
+		gr.DrawTextCentered (x + bar_w / 2, y + area_h + 0.03, Catalog.GetString ("Memory"));
 	}
 
 	private void DrawScores (CairoContextEx gr, int area_width, int area_height)
 	{
-		double y = 0.08, x = 0.05;
-		double space_small = 0.06;
+		double y = 0.04, x = 0.05;
+		double space_small = 0.02;
 		string s;
 
 		gr.Scale (area_width, area_height);
-		gr.Color = new Cairo.Color (1, 1, 1);
-		gr.Paint ();	
+		gr.DrawBackground ();
 		gr.Color = new Cairo.Color (0, 0, 0, 1);
 
-		gr.SetFontSize (0.03);
 		gr.MoveTo (x, y);
-		gr.ShowText (Catalog.GetString ("Score"));
-		DrawBand (gr, 0.03, y - 0.04);
+		gr.ShowPangoText (Catalog.GetString ("Score"), false, -1, 0);
+		DrawBand (gr, 0.03, y - 0.01);
 
-		gr.SetFontSize (0.03);
 		y += 0.08;
 		gr.MoveTo (x, y);
 
@@ -290,33 +227,29 @@ public class GameDrawingArea : DrawingArea
 		} else 
 			s = String.Empty;
 
-		gr.SetFontSize (0.03);
 		gr.MoveTo (x, y);
-
 		if (s == String.Empty)
-			gr.ShowText (String.Format (Catalog.GetString ("Games won: {0} ({1} played)"), session.GamesWon, session.GamesPlayed));	
+			gr.ShowPangoText (String.Format (Catalog.GetString ("Games won: {0} ({1} played)"), session.GamesWon, session.GamesPlayed));	
 		else 
-			gr.ShowText (String.Format (Catalog.GetString ("{0}. Games won: {1} ({2} played)"), s, session.GamesWon, session.GamesPlayed));	
+			gr.ShowPangoText (String.Format (Catalog.GetString ("{0}. Games won: {1} ({2} played)"), s, session.GamesWon, session.GamesPlayed));	
 
-		y += space_small;
-		gr.MoveTo (x, y);
-		gr.ShowText (String.Format (Catalog.GetString ("Time played {0} (average per game {1})"), session.GameTime, session.TimePerGame));
-		
 		y += 0.06;
-		DrawGraphicBar (gr, x + 0.05, y);
-		y += 0.42;
-
-		gr.SetFontSize (0.03);
 		gr.MoveTo (x, y);
-		gr.ShowText (Catalog.GetString ("Tips for your next games"));
-		DrawBand (gr, 0.03, y - 0.04);
+		gr.ShowPangoText (String.Format (Catalog.GetString ("Time played {0} (average per game {1})"), session.GameTime, session.TimePerGame));
+		
+		y += 0.1;
+		DrawGraphicBar (gr, x + 0.05, y);
+		y += 0.4;
+
+		gr.MoveTo (x, y);
+		gr.ShowPangoText (Catalog.GetString ("Tips for your next games"), false, -1, 0);
+		DrawBand (gr, 0.03, y - 0.01);
 
-		gr.SetFontSize (0.03);
 		y += 0.08;
 		for (int i = 0; i < tips_shown; i++)
 		{
-			y = gr.DrawStringWithWrapping (x, y, space_small, "- " + GetTip (random_indices[i]));
-			if (y > 0.85)
+			y = gr.DrawStringWithWrapping (x, y,  "- " + GameTips.GetTip (random_indices[i]));
+			if (y > 0.88)
 				break;
 
 			y += space_small;
@@ -325,34 +258,6 @@ public class GameDrawingArea : DrawingArea
 		gr.Stroke ();
 	}
 
-	private String GetTip (int tip)
-	{
-		switch (tip) {
-		case 0:
-			return Catalog.GetString ("Read the instructions carefully and identify the data and given clues.");
-		case 1:
-			return Catalog.GetString ("To score the player gbrainy uses the time and tips needed to complete each game.");
-		case 2:
-			return Catalog.GetString ("In logic games, elements that may seem irrelevant can be very important.");
-		case 3:
-			return Catalog.GetString ("Break the mental blocks and look into the boundaries of problems.");
-		case 4:
-			return Catalog.GetString ("Enjoy making mistakes, they are part of the learning process.");
-		case 5:
-			return Catalog.GetString ("Do all the problems, even the difficult ones. Improvement comes from practising.");
-		case 6:
-			return Catalog.GetString ("Play on a daily basis, you will notice progress soon.");
-		case 7:
-			return Catalog.GetString ("Use the Custom Game Selection to choose exactly which games you want to play.");
-		case 8:
-			return Catalog.GetString ("Use the Settings to adjust the difficulty level of the game.");
-		case 9:
-			return Catalog.GetString ("Association of elements is a common technique for remembering things.");
-		}
-
-		return string.Empty;
-	}
-
 	protected override bool OnExposeEvent (Gdk.EventExpose args)
 	{
 		if(!IsRealized)
@@ -361,8 +266,10 @@ public class GameDrawingArea : DrawingArea
 		int w, h, nw, nh;
 		double x = 0, y = 0;
 		args.Window.GetSize (out w, out h);
+
+		// TODO: This created and destroyed in every expose event
 		Cairo.Context cc = Gdk.CairoHelper.Create (args.Window);
-		CairoContextEx cr = new CairoContextEx (cc.Handle);
+		CairoContextEx cr = new CairoContextEx (cc.Handle, this);
 
 		// We want a square drawing area for the puzzles then the figures are shown as designed. 
 		// For example, squares are squares. This also makes sure that proportions are kept when resizing
@@ -388,7 +295,7 @@ public class GameDrawingArea : DrawingArea
 			puzzle.Draw (cr, nw, nh);
 			break;
 		case Modes.CountDown:
-			DrawCountDown (cr, nw, nh);
+			CountDown.Draw (cr, nw, nh);
 			break;
 		}
 
@@ -396,7 +303,105 @@ public class GameDrawingArea : DrawingArea
 		((IDisposable)cr).Dispose();
 		return base.OnExposeEvent(args);
 	}
+}
 
+public class CountDown
+{
+	static int countdown_time;
+	System.Timers.Timer timer;
+	EventHandler finish;
+	GameDrawingArea area;
+
+	public CountDown (GameDrawingArea area, EventHandler OnFinish)
+	{
+		countdown_time = 3;
+		timer = new System.Timers.Timer ();
+		timer.Elapsed += TimerUpdater;
+		timer.Interval = (1 * 1000); // 1 second
+		timer.Enabled = true;
+		finish = OnFinish;
+		this.area = area;
+	}
+
+	public void EndDrawCountDown ()
+	{
+		if (timer == null)
+			return;
+
+		timer.Enabled = false;
+		timer.Dispose ();
+		timer = null;
+	}
+
+	static public void Draw (CairoContextEx gr, int area_width, int area_height)
+	{
+		gr.Scale (area_width, area_height);
+
+		gr.Color = new Cairo.Color (0.8, 0.8, 0.8);
+		gr.Paint ();
+
+		gr.LineWidth = 0.01;
+		gr.Color = new Cairo.Color (0, 0, 0, 1);
+
+		gr.SetPangoLargeFontSize ();
+		gr.DrawTextCentered (0.5, 0.1, Catalog.GetString ("Get ready to memorize the next objects..."));
+		gr.Stroke ();
+
+		gr.SetPangoFontSize (0.35);
+		gr.MoveTo (0.37, 0.22);
+		gr.ShowPangoText (countdown_time.ToString ());
+		gr.Stroke ();
+
+		gr.Arc (0.5, 0.5, 0.25, 0, 2 * Math.PI);
+		gr.Stroke ();
+		gr.Arc (0.5, 0.5, 0.28, 0, 2 * Math.PI);
+		gr.Stroke ();
+	}
+
+	void TimerUpdater (object source, ElapsedEventArgs e)
+	{
+		lock (this) {
+			if (countdown_time == 1) {
+				EndDrawCountDown ();
+				Application.Invoke ( delegate { 
+					finish (this, EventArgs.Empty);
+				});
+			}
+			countdown_time--;
+			Application.Invoke ( delegate { area.QueueDraw (); });
+		}
+	}
 }
 
 
+class GameTips
+{
+	static public String GetTip (int tip)
+	{
+		switch (tip) {
+		case 0:
+			return Catalog.GetString ("Read the instructions carefully and identify the data and given clues.");
+		case 1:
+			return Catalog.GetString ("To score the player gbrainy uses the time and tips needed to complete each game.");
+		case 2:
+			return Catalog.GetString ("In logic games, elements that may seem irrelevant can be very important.");
+		case 3:
+			return Catalog.GetString ("Break the mental blocks and look into the boundaries of problems.");
+		case 4:
+			return Catalog.GetString ("Enjoy making mistakes, they are part of the learning process.");
+		case 5:
+			return Catalog.GetString ("Do all the problems, even the difficult ones. Improvement comes from practising.");
+		case 6:
+			return Catalog.GetString ("Play on a daily basis, you will notice progress soon.");
+		case 7: // Translators: Custom Game Selection is a menu option
+			return Catalog.GetString ("Use the 'Custom Game Selection' to choose exactly which games you want to play.");
+		case 8:
+			return Catalog.GetString ("Use the Settings to adjust the difficulty level of the game.");
+		case 9:
+			return Catalog.GetString ("Association of elements is a common technique for remembering things.");
+		}
+
+		return string.Empty;
+	}
+}
+
