@@ -26,11 +26,13 @@ using Gdk;
 using Gnome;
 using Mono.Unix;
 using System.Text;
-
+using System.Globalization;
+using System.Threading;
 
 public class gbrainy: Program
 {
 	[Glade.Widget("gbrainy")] Gtk.Window app_window;
+	[Glade.Widget ("toolbar_item")] Gtk.CheckMenuItem toolbar_menuitem;
 	[Glade.Widget] Box drawing_vbox;
 	[Glade.Widget] Gtk.TextView question_textview;
 	[Glade.Widget] Gtk.TextView solution_textview;
@@ -40,7 +42,7 @@ public class gbrainy: Program
 	[Glade.Widget] Gtk.Button next_button;
 	[Glade.Widget] Gtk.Statusbar statusbar;
 	[Glade.Widget] Gtk.Toolbar toolbar;
-	[Glade.Widget] Gtk.Label label_answser;
+	[Glade.Widget] Gtk.Label label_answer;
 	GameDrawingArea drawing_area;
 	GameSession session;
 	const int ok_buttonid = -5;
@@ -48,6 +50,7 @@ public class gbrainy: Program
 	Gtk.TextBuffer question_buffer;
 	Gtk.TextBuffer solution_buffer;
 	TextTag tag_green;
+	bool low_res = false;
 	
 	public static PlayerHistory history = null;
 	public static Preferences preferences = null;
@@ -58,6 +61,7 @@ public class gbrainy: Program
 		Gdk.Color color;
 
 		Catalog.Init ("gbrainy", Defines.GNOME_LOCALE_DIR);
+		FixLocaleInfo ();
 
 		IconFactory icon_factory = new IconFactory ();
                 AddIcon (icon_factory, "logic-games", "logic-games-32.png");
@@ -129,14 +133,27 @@ public class gbrainy: Program
 		if (preferences == null)
 			preferences = new Preferences ();
 
+		session.GameManager.Difficulty = (Game.Difficulty) preferences.GetIntValue (Preferences.DifficultyKey);
 		drawing_area = new GameDrawingArea ();
+
+		// For low resolutions, hide the toolbar and made the drawing area smaller
+		if (drawing_area.Screen.Width> 0 && drawing_area.Screen.Height > 0) {
+			if (drawing_area.Screen.Height < 700) {
+				drawing_vbox.HeightRequest = 300;
+				low_res = true;
+			}
+		}
+
 		drawing_vbox.Add (drawing_area);
 		//app_window.Resize (500, 700);
 		//app_window.SizeAllocated += new SizeAllocatedHandler (OnSizeAllocated);
 		app_window.IconName = "gbrainy";
 		app_window.ShowAll ();
-	
-		color = label_answser.Style.Background (StateType.Normal);
+
+		if (preferences.GetBoolValue (Preferences.Toolbar) == false || low_res == true)
+			toolbar_menuitem.Active = false;
+
+		color = label_answer.Style.Background (StateType.Normal);
 		question_textview.ModifyBase (Gtk.StateType.Normal, color);
 		solution_textview.ModifyBase (Gtk.StateType.Normal, color);
 
@@ -144,6 +161,71 @@ public class gbrainy: Program
 		//OnMemoryOnly (this, EventArgs.Empty); // temp
 	}
 
+		/* Taken from locale.h  */
+		[StructLayout (LayoutKind.Sequential)]
+		public struct lconv
+		{
+			public string decimal_point;
+			public string thousands_sep;		
+			public string grouping;
+			public string int_curr_symbol;
+			public string currency_symbol;
+			public string mon_decimal_point;
+			public string mon_thousands_sep;
+			public string mon_grouping;
+			public string positive_sign;
+			public string negative_sign;
+			char int_frac_digits;
+			char frac_digits;
+			char p_cs_precedes;
+			char p_sep_by_space;
+			char n_cs_precedes;
+			char n_sep_by_space;
+			char p_sign_posn;
+			char n_sign_posn;
+			char int_p_cs_precedes;
+			char int_p_sep_by_space;
+			char int_n_cs_precedes;
+			char int_n_sep_by_space;
+			char int_p_sign_posn;
+			char int_n_sign_posn;
+		}
+
+
+	[DllImport("libc")]
+	static extern IntPtr localeconv ();
+
+	// Mono supports less locales that Unix systems
+	// To overcome this limitation we setup the right locale parameters
+	// when the Mono locale is InvariantCulture, that is, when the user's locale
+	// has not been identified and the default Mono locale is used
+	//
+	// See: https://bugzilla.novell.com/show_bug.cgi?id=420468
+	// 
+	private void FixLocaleInfo ()
+	{
+		IntPtr st = IntPtr.Zero;
+		lconv lv;
+		int platform = (int) Environment.OSVersion.Platform;
+		
+		if (platform != 4 && platform != 128) // Only in Unix based systems
+			return;
+
+		if (CultureInfo.CurrentCulture != CultureInfo.InvariantCulture) // Culture well supported
+			return;
+
+		try {
+			st = localeconv ();
+			if (st == IntPtr.Zero) return;
+
+			lv = (lconv) Marshal.PtrToStructure (st, typeof (lconv));
+			CultureInfo culture =  (CultureInfo) CultureInfo.CurrentCulture.Clone ();
+			culture.NumberFormat.NumberDecimalSeparator = lv.decimal_point;
+			Thread.CurrentThread.CurrentCulture = culture;
+		}
+		catch (Exception) {}
+	}
+
 	public void UpdateStatusBar ()
 	{
 		statusbar.Push (0, session.StatusText);
@@ -463,6 +545,8 @@ public class gbrainy: Program
 		requisition =  toolbar.SizeRequest ();
 		app_window.GetSize (out width, out height);
 		toolbar.Visible = !toolbar.Visible;
+		preferences.SetBoolValue (Preferences.Toolbar, toolbar.Visible);
+		preferences.Save ();
 		app_window.Resize (width, height - requisition.Height);
 	}
 
